@@ -42,7 +42,10 @@ typedef void (* RsvgSizeFunc) (gint     *width,
 			       gpointer  user_data);
 
 
+void        rsvg_set_default_dpi          (double dpi);
+
 RsvgHandle *rsvg_handle_new               (void);
+void        rsvg_handle_set_dpi           (RsvgHandle * handle, double dpi);
 void        rsvg_handle_set_size_callback (RsvgHandle      *handle,
 					   RsvgSizeFunc     size_func,
 					   gpointer         user_data,
@@ -57,20 +60,27 @@ GdkPixbuf  *rsvg_handle_get_pixbuf        (RsvgHandle      *handle);
 void        rsvg_handle_free              (RsvgHandle      *handle);
 
 /* convenience API */
-GdkPixbuf  *rsvg_pixbuf_from_file             (const gchar  *file_name,
-					       GError      **error);
-GdkPixbuf  *rsvg_pixbuf_from_file_at_zoom     (const gchar  *file_name,
-					       double        x_zoom,
-					       double        y_zoom,
-					       GError      **error);
-GdkPixbuf  *rsvg_pixbuf_from_file_at_size     (const gchar  *file_name,
-					       gint          width,
-					       gint          height,
-					       GError      **error);
-GdkPixbuf  *rsvg_pixbuf_from_file_at_max_size (const gchar  *file_name,
-					       gint          max_width,
-					       gint          max_height,
-					       GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file                  (const gchar  *file_name,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_zoom          (const gchar  *file_name,
+						    double        x_zoom,
+						    double        y_zoom,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_size          (const gchar  *file_name,
+						    gint          width,
+						    gint          height,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_max_size      (const gchar  *file_name,
+						    gint          max_width,
+						    gint          max_height,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_zoom_with_max (const gchar  *file_name,
+						    double        x_zoom,
+						    double        y_zoom,
+						    gint          max_width,
+						    gint          max_height,
+						    GError      **error);
+
 
 G_END_DECLS
 
